==> apache-parquet-1.12.3.tar.gz: apache-parquet-1.12.3/parquet-hadoop/src/main/java/org/apache/parquet/hadoop/util/HadoopCodecs.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.parquet.hadoop.util;

import org.apache.hadoop.conf.Configuration;
import org.apache.parquet.bytes.ByteBufferAllocator;
import org.apache.parquet.compression.CompressionCodecFactory;
import org.apache.parquet.hadoop.CodecFactory;

public class HadoopCodecs {
  public static CompressionCodecFactory newFactory(int sizeHint) {
    return new CodecFactory(new Configuration(), sizeHint);
  }

  public static CompressionCodecFactory newFactory(Configuration conf, int sizeHint) {
    return new CodecFactory(conf, sizeHint);
  }

  public static CompressionCodecFactory newDirectFactory(Configuration conf, ByteBufferAllocator allocator, int sizeHint) {
    return CodecFactory.createDirectCodecFactory(conf, allocator, sizeHint);
  }
}

==> apache-parquet-1.14.3.tar.gz: apache-parquet-1.14.3/parquet-hadoop/src/main/java/org/apache/parquet/hadoop/util/HadoopCodecs.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.parquet.hadoop.util;

import org.apache.hadoop.conf.Configuration;
import org.apache.parquet.bytes.ByteBufferAllocator;
import org.apache.parquet.compression.CompressionCodecFactory;
import org.apache.parquet.conf.ParquetConfiguration;
import org.apache.parquet.hadoop.CodecFactory;

public class HadoopCodecs {
  public static CompressionCodecFactory newFactory(int sizeHint) {
    return new CodecFactory(new Configuration(), sizeHint);
  }

  public static CompressionCodecFactory newFactory(Configuration conf, int sizeHint) {
    return new CodecFactory(conf, sizeHint);
  }

  public static CompressionCodecFactory newFactory(ParquetConfiguration conf, int sizeHint) {
    return new CodecFactory(conf, sizeHint);
  }

  public static CompressionCodecFactory newDirectFactory(
      Configuration conf, ByteBufferAllocator allocator, int sizeHint) {
    return CodecFactory.createDirectCodecFactory(conf, allocator, sizeHint);
  }
}
